@@ -21,9 +21,9 @@ from pytorch_lightning.utilities import move_data_to_device
 from leanai.core.config import DictLike
 from leanai.core.definitions import SPLIT_TEST, SPLIT_TRAIN, SPLIT_VAL
 from leanai.core.tensorboard import TensorBoardLogger
-from leanai.core.logging import warn, info, set_logger, get_timestamp
+from leanai.core.logging import debug, warn, info, set_logger, get_timestamp
 from leanai.data.dataloader import DataLoader
-from leanai.training.losses.loss import Loss
+import leanai.training.losses.loss as loss
 
 
 def set_seeds():
@@ -123,8 +123,10 @@ class Experiment(pl.LightningModule):
         self.config = config
         self._InputType = InputType
         if example_input is not None:
+            debug("Initializing model")
             self.example_input_array = example_input
             self._run_model_on_example(example_input)
+            debug("Model initialized")
         self._meta_data_logging = meta_data_logging
         set_logger(os.path.join(output_path, version), log_code=True)
 
@@ -134,9 +136,6 @@ class Experiment(pl.LightningModule):
         self._load_dataset = None
         self._build_optimizer = None
 
-    def configure_gradient_clipping(self, optimizer: Optimizer, optimizer_idx: int, gradient_clip_val: Optional[Union[int, float]] = None, gradient_clip_algorithm: Optional[str] = None):
-        return super().configure_gradient_clipping(optimizer, optimizer_idx, gradient_clip_val=gradient_clip_val, gradient_clip_algorithm=gradient_clip_algorithm)
-
     def _run_model_on_example(self, example_input):
         if isinstance(example_input, Tensor):
             example_input = (example_input,)
@@ -146,12 +145,6 @@ class Experiment(pl.LightningModule):
         else:
             self.model(*inp)
 
-    def _dict_to_callable(self, spec):
-        params = dict(**spec)
-        constructor = params["type"]
-        del params["type"]
-        return constructor, params
-
     def run_training(
         self,
         load_dataset: Union[Callable, Dict],
@@ -186,14 +179,8 @@ class Experiment(pl.LightningModule):
         self._load_dataset = load_dataset
         self._build_optimizer = build_optimizer
         self._num_workers = num_dataloader_threads
-        if isinstance(build_loss, dict):
-            constructor, params = self._dict_to_callable(build_loss)
-            if isinstance(constructor, Loss.__class__):
-                self.loss = constructor(parent=self, **params)
-            else:
-                self.loss = constructor(**params)
-        else:
-            self.loss = build_loss(self)
+        self.loss = build_loss()
+        loss._active_experiment = self
         gpus = int(_env_defaults(gpus, "SLURM_GPUS", 1))
         nodes = int(_env_defaults(nodes, "SLURM_NODES", 1))
         trainer = pl.Trainer(
@@ -209,6 +196,8 @@ class Experiment(pl.LightningModule):
             resume_from_checkpoint=self._find_checkpoint(checkpoint),
             accelerator="ddp" if gpus > 1 else None
         )
+        debug("Experiment before trainer.fit(self)")
+        debug(self)
         return trainer.fit(self)
 
     def run_inference(
@@ -251,17 +240,15 @@ class Experiment(pl.LightningModule):
             ),
             accelerator="ddp" if gpus > 1 else None
         )
+        debug("Experiment before trainer.test(self)")
+        debug(self)
         return trainer.test(self)
 
     # **********************************************
     # Configure training
     # **********************************************
     def configure_optimizers(self):
-        if isinstance(self._build_optimizer, dict):
-            constructor, params = self._dict_to_callable(self._build_optimizer)
-            return constructor(self.parameters(), **params)
-        else:
-            return self._build_optimizer(self)
+        return self._build_optimizer(self.parameters())
 
     # **********************************************
     # Steping through the model
@@ -302,19 +289,10 @@ class Experiment(pl.LightningModule):
     # **********************************************
     def setup(self, stage=None):
         if not self._testing:
-            if isinstance(self._load_dataset, dict):
-                fun, params = self._dict_to_callable(self._load_dataset)
-                self.train_data = fun(split=SPLIT_TRAIN, **params)
-                self.val_data = fun(split=SPLIT_VAL, **params)
-            else:
-                self.train_data = self._load_dataset(self, SPLIT_TRAIN)
-                self.val_data = self._load_dataset(self, SPLIT_VAL)
+            self.train_data = self._load_dataset(split=SPLIT_TRAIN)
+            self.val_data = self._load_dataset(split=SPLIT_VAL)
         else:
-            if isinstance(self._load_dataset, dict):
-                fun, params = self._dict_to_callable(self._load_dataset)
-                self.test_data = fun(**params)
-            else:
-                self.test_data = self._load_dataset(self)
+            self.test_data = self._load_dataset()
 
     def train_dataloader(self):
         shuffle = True
