@@ -5,10 +5,10 @@
 """
 from torch.nn import Module
 from torch.nn.modules.dropout import Dropout as _Dropout
-from leanai.model.module_registry import add_module
+from leanai.model.module_registry import register_module
 
 
-@add_module()
+@register_module()
 class Dropout(Module):
     def __init__(self, p: float, inplace: bool = False):
         """
