@@ -9,10 +9,10 @@ import torch
 from torch import Tensor
 from torch.nn import Module
 from leanai.core.annotations import RunOnlyOnce
-from leanai.model.module_registry import add_module
+from leanai.model.module_registry import register_module
 
 
-@add_module()
+@register_module()
 class Gather(Module):
     def __init__(self, axis):
         """
@@ -59,7 +59,7 @@ class Gather(Module):
         return torch.stack([torch.index_select(input_tensor[i], batchless_axis, indices[i]) for i in range(self.batch_size)])
 
 
-@add_module()
+@register_module()
 class TopKIndices(Module):
     def __init__(self, k):
         """
@@ -80,7 +80,7 @@ class TopKIndices(Module):
         return torch.topk(input_tensor, self.k).indices
 
 
-@add_module()
+@register_module()
 class GatherTopKIndices(Module):
     def __init__(self, k: int, background_class_idx: int = 0):
         """
@@ -109,7 +109,7 @@ class GatherTopKIndices(Module):
         return self.gather(input_tensor, indices), self.gather(scores, indices)
 
 
-@add_module()
+@register_module()
 class GatherTopKIndicesOnIndexed(Module):
     def __init__(self, k: int, background_class_idx: int = 0):
         """
