@@ -12,7 +12,7 @@ from leanai.training.loss_registry import build_loss, register_loss
 
 @register_loss()
 class NormalizedLoss(Loss):
-    def __init__(self, parent, loss, name = None, initial_sigma=1):
+    def __init__(self, loss, name = None, initial_sigma=1):
         """
         Normalize a loss by learning the variance.
 
@@ -21,8 +21,8 @@ class NormalizedLoss(Loss):
         :param name: The name under which to log the sigmas.
         :param initial_sigma: The initial sigma values.
         """
-        super().__init__(parent=parent)
-        self._loss = build_loss(loss, self)
+        super().__init__()
+        self._loss = build_loss(loss)
         self.name = name
         self.sigma = Parameter(torch.tensor(initial_sigma, dtype=torch.float32, requires_grad=True), requires_grad=True)
 
@@ -42,11 +42,11 @@ class NormalizedLoss(Loss):
 
 
 @register_loss()
-def MultiLossV2(parent, **losses) -> SumLoss:
+def MultiLossV2(**losses) -> SumLoss:
     """
     Normalizes the losses by variance estimation and then sums them.
 
     :param parent: The parent for the loss.
     :param **losses: Provide the losses you want to have fused as named parameters to the constructor. Losses get applied to y_pred and y_true, then logged to tensorboard and finally fused.
     """
-    return SumLoss(parent, **{k: NormalizedLoss(parent, build_loss(v, parent), name=k) for k, v in losses.items()})
+    return SumLoss(**{k: NormalizedLoss(build_loss(v), name=k) for k, v in losses.items()})
